@@ -433,8 +433,10 @@ def create_pfile(output_filename, feature_count, data):
     logging.info(command)
     return_code = os.system(command)
     if return_code != 0:
-        logging.error("pfile_create failed with return code %i." % return_code)
+        logging.error("pfile_create failed with return code %i.", return_code)
         sys.exit(-1)
+
+    # Cleanup
     os.remove(input_filename)
 
 
@@ -520,25 +522,39 @@ def evaluate_model(recording, model_folder, verbose=False):
     os.remove(output_filename)
 
 
+def get_index2latex(model_description):
+    """Get a dictionary that maps indices to LaTeX commands.
+
+    :param model_description: A model description file that points to
+                              a feature folder where an
+                              ``index2formula_id.csv`` has to be.
+    :returns: Dictionary that maps indices to LaTeX commands
+    """
+    index2latex = {}
+    translation_csv = os.path.join(get_project_root(),
+                                   model_description["data-source"],
+                                   "index2formula_id.csv")
+    with open(translation_csv) as csvfile:
+        csvreader = csv.DictReader(csvfile, delimiter=',', quotechar='"')
+        for row in csvreader:
+            index2latex[int(row['index'])] = row['latex']
+    return index2latex
+
+
 def classify_single_recording(raw_data_json, model_folder, verbose=False):
     """Get the classification as a list of tuples. The first value is the
        LaTeX code, the second value is the probability.
     """
     evaluation_file = evaluate_model(raw_data_json, model_folder, verbose)
-    project_root = get_project_root()
     with open(os.path.join(model_folder, "info.yml")) as ymlfile:
         model_description = yaml.load(ymlfile)
-    translation_csv = os.path.join(project_root,
-                                   model_description["data-source"],
-                                   "index2formula_id.csv")
-    index2latex = {}
-    with open(translation_csv) as csvfile:
-        spamreader = csv.DictReader(csvfile, delimiter=',', quotechar='"')
-        for row in spamreader:
-            index2latex[int(row['index'])] = row['latex']
+
+    index2latex = get_index2latex(model_description)
+
+    # Map line to probabilites for latex commands
     with open(evaluation_file) as f:
-        content = f.read()
-    probabilities = map(float, content.split(" "))
+        probabilities = f.read()
+    probabilities = map(float, probabilities.split(" "))
     results = []
     for index, probability in enumerate(probabilities):
         results.append((index2latex[index], probability))
